/* -----------------------------------------------------------------------------
 * Copyright (c) 2013-2016 ARM Ltd.
 *
 * This software is provided 'as-is', without any express or implied warranty.
 * In no event will the authors be held liable for any damages arising from
 * the use of this software. Permission is granted to anyone to use this
 * software for any purpose, including commercial applications, and to alter
 * it and redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software in
 *    a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source distribution.
 *
 *
 * $Date:        8. June 2016
 * $Revision:    V2.0
 *
 * Project:      I2C Driver Definitions for NXP LPC15xx
 * -------------------------------------------------------------------------- */

#ifndef __I2C_LPC15XX_H
#define __I2C_LPC15XX_H

#include <string.h>

#include "chip.h"
#include "Driver_I2C.h"

#include "RTE_Components.h"
#include "RTE_Device.h"

/* I2C0 Pins */
#define I2C0_SDA_PORT           (0U)
#define I2C0_SDA_PIN            (23U)
#define I2C0_SCL_PORT           (0U)
#define I2C0_SCL_PIN            (22U)


/* IOCON settings for I2C pins */
#define I2C_PIN_IOCON_GPIO      (IOCON_STDI2C_EN)
#define I2C_PIN_IOCON_STANDARD  (IOCON_SFI2C_EN)
#define I2C_PIN_IOCON_FAST      (IOCON_SFI2C_EN)
#define I2C_PIN_IOCON_FAST_PLUS (IOCON_FASTI2C_EN)
#define I2C_PIN_IOCON_HIGH      (IOCON_FASTI2C_EN)

/* I2C interrupt mask */
#define I2C_MASTER_INTERRUPTS   (I2C_INTENSET_MSTPENDING  | \
                                 I2C_INTENSET_MSTRARBLOSS | \
                                 I2C_INTENSET_MSTSTSTPERR)

#define I2C_SLAVE_INTERRUPTS    (I2C_INTENSET_SLVPENDING | \
                                 I2C_INTENSET_SLVNOTSTR  | \
                                 I2C_INTENSET_SLVDESEL)

/* I2C interrupt mask */
#define I2C_MASTER_INTERRUPTS   (I2C_INTENSET_MSTPENDING  | \
                                 I2C_INTENSET_MSTRARBLOSS | \
                                 I2C_INTENSET_MSTSTSTPERR)

#define I2C_SLAVE_INTERRUPTS    (I2C_INTENSET_SLVPENDING | \
                                 I2C_INTENSET_SLVNOTSTR  | \
                                 I2C_INTENSET_SLVDESEL)

/* I2C Driver state flags */
#define I2C_INIT       (uint8_t)(1U << 0)   // Driver initialized
#define I2C_POWER      (uint8_t)(1U << 1)   // Driver power on
#define I2C_SLAVE10BIT (uint8_t)(1U << 2)   // Slave uses 10-bit addressing

/* Transfer status flags */
#define XFER_CTRL_XPENDING  ((uint8_t)0x01) // Transfer pending
#define XFER_CTRL_ADDR_DONE ((uint8_t)0x02) // Addressing done

/* I2C Transfer Information (Run-Time) */
typedef struct I2C_XFER_INFO {
  uint8_t              *data;               // Data pointer
  uint32_t              num;                // Number of data to transfer
  uint32_t              cnt;                // Data transfer counter
  uint16_t              addr;               // Device address
  uint8_t               ctrl;               // Transfer control flags
} I2C_TRANSFER_INFO;

/* I2C Control Information */
typedef struct {
  ARM_I2C_SignalEvent_t cb_event;           // Event callback
  ARM_I2C_STATUS        status;             // Status flags
  I2C_TRANSFER_INFO     xfer;
  uint8_t               flags;              // Control and state flags
} I2C_INFO;


/* I2C Resource Configuration */
typedef struct {
  LPC_I2C_T            *reg;                // I2C register interface
  I2C_INFO             *info;               // Run-Time control information
} const I2C_RESOURCES;

#endif /* __I2C_LPC15XX_H */
